@@ -2,10 +2,10 @@
 ## State distribution plot
 ## ========================
 
-seqdplot <- function(seqdata, group=NULL, main=NULL, ...) {
+seqdplot <- function(seqdata, group=NULL, main="auto", ...) {
 	seqplot(seqdata, group=group, type="d", main=main, ...)
 }
 
-seqdHplot <- function(seqdata, group=NULL, main=NULL, ...) {
+seqdHplot <- function(seqdata, group=NULL, main="auto", ...) {
 	seqplot(seqdata, group=group, type="dH", main=main, ...)
 }
